@@ -3,6 +3,7 @@
 namespace Drupal\Core\Installer;
 
 use Drupal\Core\DrupalKernel;
+use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Extend DrupalKernel to handle force some kernel behaviors.
@@ -68,4 +69,32 @@ class InstallerKernel extends DrupalKernel {
     return $profile;
   }
 
+  /**
+   * Returns TRUE if a Drupal installation is currently being attempted.
+   *
+   * @return bool
+   *   TRUE if the installation is currently being attempted.
+   */
+  public static function installationAttempted() {
+    // This cannot rely on the MAINTENANCE_MODE constant, since that would
+    // prevent tests from using the non-interactive installer, in which case
+    // Drupal only happens to be installed within the same request, but
+    // subsequently executed code does not involve the installer at all.
+    // @see install_drupal()
+    return isset($GLOBALS['install_state']) && empty($GLOBALS['install_state']['installation_finished']);
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  protected function attachSynthetic(ContainerInterface $container): void {
+    parent::attachSynthetic($container);
+
+    // Reset any existing container in order to avoid holding on to old object
+    // references, otherwise memory usage grows exponentially with each rebuild
+    // when multiple modules are being installed.
+    // @todo Move this to the parent class after https://www.drupal.org/i/2066993
+    $this->container?->reset();
+  }
+
 }
