@@ -15,6 +15,7 @@ use Drupal\KernelTests\KernelTestBase;
  * applied.
  *
  * @group Asset
+ * @group #slow
  */
 class ResolvedLibraryDefinitionsFilesMatchTest extends KernelTestBase {
 
@@ -98,6 +99,20 @@ class ResolvedLibraryDefinitionsFilesMatchTest extends KernelTestBase {
   protected function setUp(): void {
     parent::setUp();
 
+    // Install all core themes.
+    sort($this->allThemes);
+    $this->container->get('theme_installer')->install($this->allThemes);
+
+    $this->themeHandler = $this->container->get('theme_handler');
+    $this->themeInitialization = $this->container->get('theme.initialization');
+    $this->themeManager = $this->container->get('theme.manager');
+    $this->libraryDiscovery = $this->container->get('library.discovery');
+  }
+
+  /**
+   * Ensures that all core module and theme library files exist.
+   */
+  public function testCoreLibraryCompleteness(): void {
     // Enable all core modules.
     $all_modules = $this->container->get('extension.list.module')->getList();
     $all_modules = array_filter($all_modules, function ($module) {
@@ -140,21 +155,37 @@ class ResolvedLibraryDefinitionsFilesMatchTest extends KernelTestBase {
     }
     sort($this->allModules);
     $this->container->get('module_installer')->install($this->allModules);
-
-    // Install all core themes.
-    sort($this->allThemes);
-    $this->container->get('theme_installer')->install($this->allThemes);
-
-    $this->themeHandler = $this->container->get('theme_handler');
-    $this->themeInitialization = $this->container->get('theme.initialization');
-    $this->themeManager = $this->container->get('theme.manager');
+    // Get a library discovery from the new container.
     $this->libraryDiscovery = $this->container->get('library.discovery');
+
+    $this->assertLibraries();
   }
 
   /**
-   * Ensures that all core module and theme library files exist.
+   * Ensures that module and theme library files exist for a deprecated modules.
+   *
+   * @group legacy
    */
-  public function testCoreLibraryCompleteness(): void {
+  public function testCoreLibraryCompletenessDeprecated(): void {
+    // Find and install deprecated modules to test.
+    $all_modules = $this->container->get('extension.list.module')->getList();
+    $deprecated_modules_to_test = array_filter($all_modules, function ($module) {
+      if ($module->origin == 'core'
+        && $module->info[ExtensionLifecycle::LIFECYCLE_IDENTIFIER] === ExtensionLifecycle::DEPRECATED) {
+        return TRUE;
+      }
+    });
+    $this->container->get('module_installer')->install(array_keys($deprecated_modules_to_test));
+    $this->libraryDiscovery = $this->container->get('library.discovery');
+    $this->allModules = array_keys(\Drupal::moduleHandler()->getModuleList());
+
+    $this->assertLibraries();
+  }
+
+  /**
+   * Asserts the libraries for modules and themes exist.
+   */
+  public function assertLibraries(): void {
     // First verify all libraries with no active theme.
     $this->verifyLibraryFilesExist($this->getAllLibraries());
 
@@ -163,7 +194,7 @@ class ResolvedLibraryDefinitionsFilesMatchTest extends KernelTestBase {
     // and these changes are only applied for the active theme.
     foreach ($this->allThemes as $theme) {
       $this->themeManager->setActiveTheme($this->themeInitialization->getActiveThemeByName($theme));
-      $this->libraryDiscovery->clearCachedDefinitions();
+      $this->libraryDiscovery->clear();
 
       $this->verifyLibraryFilesExist($this->getAllLibraries());
     }
@@ -176,7 +207,7 @@ class ResolvedLibraryDefinitionsFilesMatchTest extends KernelTestBase {
    *   An array of library definitions, keyed by extension, then by library, and
    *   so on.
    */
-  protected function verifyLibraryFilesExist($library_definitions) {
+  protected function verifyLibraryFilesExist($library_definitions): void {
     foreach ($library_definitions as $extension => $libraries) {
       foreach ($libraries as $library_name => $library) {
         if (in_array("$extension/$library_name", $this->librariesToSkip)) {
